@@ -105,7 +105,8 @@ list_key_press_event (GtkWidget *clist, GdkEventKey *k, gpointer user_data)
   
   if (k->keyval == GDK_Down)
   {
-    gtk_clist_select_row(GTK_CLIST(clist),row + 1, 0);
+    gtk_clist_select_row (GTK_CLIST(clist),row + 1, 0);
+
     if (row == lastrow)
       {
         lastrow = -1;
@@ -117,7 +118,19 @@ list_key_press_event (GtkWidget *clist, GdkEventKey *k, gpointer user_data)
         return FALSE;
       }
   }
+
+  if (k->keyval == GDK_Left)
+    {
+      gtk_date_sel_move_day (datesel, -1);
+      return TRUE;
+    }
   
+  if (k->keyval == GDK_Right)
+    {
+      gtk_date_sel_move_day (datesel, 1);
+      return TRUE;
+    }
+
   if (k->keyval == GDK_Return)
   {
     if (row >= 0)
@@ -357,7 +370,6 @@ day_view_update ()
       if (day_events[hour]) 
         event_db_list_destroy (day_events[hour]);
       day_events[hour] = event_db_untimed_list_for_period (start, end-1, FALSE);
-      
       for (iter = day_events[hour]; iter; iter = iter->next)
 	    ((event_t)iter->data)->mark = FALSE;
     }
@@ -506,7 +518,6 @@ update_hook_callback()
 {
   gtk_date_sel_set_time (GTK_DATE_SEL (datesel), viewtime);
   gtk_widget_draw (datesel, NULL);
-      
   day_view_update ();
 }
 
